@@ -98,8 +98,8 @@ typedef struct
 	gboolean           should_interrupt_stack;
 } GsAuthMessageHandlerData;
 
-static GCond  *message_handled_condition;
-static GMutex *message_handler_mutex;
+static GCond  message_handled_condition;
+static GMutex message_handler_mutex;
 
 GQuark
 gs_auth_error_quark (void)
@@ -194,7 +194,7 @@ gs_auth_queued_message_handler (GsAuthMessageHandlerData *data)
 		g_message ("Waiting for lock");
 	}
 
-	g_mutex_lock (message_handler_mutex);
+	g_mutex_lock (&message_handler_mutex);
 
 	if (gs_auth_get_verbose ())
 	{
@@ -208,8 +208,8 @@ gs_auth_queued_message_handler (GsAuthMessageHandlerData *data)
 
 	data->should_interrupt_stack = res == FALSE;
 
-	g_cond_signal (message_handled_condition);
-	g_mutex_unlock (message_handler_mutex);
+	g_cond_signal (&message_handled_condition);
+	g_mutex_unlock (&message_handler_mutex);
 
 	if (gs_auth_get_verbose ())
 	{
@@ -233,7 +233,7 @@ gs_auth_run_message_handler (struct pam_closure *c,
 	data.resp = resp;
 	data.should_interrupt_stack = TRUE;
 
-	g_mutex_lock (message_handler_mutex);
+	g_mutex_lock (&message_handler_mutex);
 
 	/* Queue the callback in the gui (the main) thread
 	 */
@@ -246,9 +246,9 @@ gs_auth_run_message_handler (struct pam_closure *c,
 
 	/* Wait for the response
 	 */
-	g_cond_wait (message_handled_condition,
-	             message_handler_mutex);
-	g_mutex_unlock (message_handler_mutex);
+	g_cond_wait (&message_handled_condition,
+	             &message_handler_mutex);
+	g_mutex_unlock (&message_handler_mutex);
 
 	if (gs_auth_get_verbose ())
 	{
@@ -380,18 +380,6 @@ close_pam_handle (int status)
 		}
 	}
 
-	if (message_handled_condition != NULL)
-	{
-		g_cond_free (message_handled_condition);
-		message_handled_condition = NULL;
-	}
-
-	if (message_handler_mutex != NULL)
-	{
-		g_mutex_free (message_handler_mutex);
-		message_handler_mutex = NULL;
-	}
-
 	return TRUE;
 }
 
@@ -464,8 +452,8 @@ create_pam_handle (const char      *username,
 	}
 
 	ret = TRUE;
-	message_handled_condition = g_cond_new ();
-	message_handler_mutex = g_mutex_new ();
+	g_cond_init (&message_handled_condition);
+	g_mutex_init (&message_handler_mutex);
 
 out:
 	if (status_code != NULL)
@@ -675,9 +663,9 @@ gs_auth_pam_verify_user (pam_handle_t *handle,
 	watch_id = g_io_add_watch (channel, G_IO_ERR | G_IO_HUP,
 	                           (GIOFunc) gs_auth_loop_quit, &thread_done);
 
-	auth_thread = g_thread_create ((GThreadFunc) gs_auth_thread_func,
-	                               GINT_TO_POINTER (auth_operation_fds[1]),
-	                               TRUE, NULL);
+	auth_thread = g_thread_new ("auththread",
+                                    (GThreadFunc) gs_auth_thread_func,
+                                    GINT_TO_POINTER (auth_operation_fds[1]));
 
 	if (auth_thread == NULL)
 	{
