@@ -78,9 +78,9 @@ static DBusHandlerResult gs_listener_message_handler    (DBusConnection  *connec
 #define CK_MANAGER_INTERFACE "org.freedesktop.ConsoleKit.Manager"
 #define CK_SESSION_INTERFACE "org.freedesktop.ConsoleKit.Session"
 
-#define SESSION_NAME         "org.mate.SessionManager"
-#define SESSION_PATH         "/org/mate/SessionManager"
-#define SESSION_INTERFACE    "org.mate.SessionManager"
+#define SESSION_NAME         "org.gnome.SessionManager"
+#define SESSION_PATH         "/org/gnome/SessionManager"
+#define SESSION_INTERFACE    "org.gnome.SessionManager"
 
 #define TYPE_MISMATCH_ERROR GS_LISTENER_INTERFACE ".TypeMismatch"
 
@@ -1541,21 +1541,10 @@ _listener_message_path_is_our_session (GSListener  *listener,
 		return FALSE;
 
 	if (listener->priv->session_id == NULL)
-	return FALSE;
+		return FALSE;
 
-#ifdef WITH_SYSTEMD
-	/* The bus object path is simply the actual session ID
-	* prefixed to make it a bus path */
-	if (listener->priv->have_systemd)
-		return g_str_has_prefix (ssid, SYSTEMD_LOGIND_SESSION_PATH "/")
-			&& strcmp (ssid + sizeof (SYSTEMD_LOGIND_SESSION_PATH),
-			listener->priv->session_id) == 0;
-#endif
-
-#ifdef WITH_CONSOLE_KIT
 	if (strcmp (ssid, listener->priv->session_id) == 0)
 		return TRUE;
-#endif
 
 	return FALSE;
 }
@@ -2340,20 +2329,45 @@ query_session_id (GSListener *listener)
 
 #ifdef WITH_SYSTEMD
 	if (listener->priv->have_systemd) {
-		char *t;
-		int r;
+		dbus_uint32_t pid = getpid();
 
-		r = sd_pid_get_session (0, &t);
-		if (r < 0) {
-			gs_debug ("Couldn't determine our own session id: %s", strerror (-r));
+		message = dbus_message_new_method_call (SYSTEMD_LOGIND_SERVICE,
+		                                        SYSTEMD_LOGIND_PATH,
+							SYSTEMD_LOGIND_INTERFACE,
+							"GetSessionByPID");
+		if (message == NULL)
+		{
+			gs_debug ("Couldn't allocate the dbus message");
 			return NULL;
 		}
 
-		/* t is allocated with malloc(), we need it with g_malloc() */
-		ssid = g_strdup(t);
-		free (t);
+		if (dbus_message_append_args (message,
+					      DBUS_TYPE_UINT32,
+					      &pid, DBUS_TYPE_INVALID) == FALSE)
+		{
+			gs_debug ("Couldn't add args to the dbus message");
+			return NULL;
+		}
 
-		return ssid;
+		/* FIXME: use async? */
+		reply = dbus_connection_send_with_reply_and_block (listener->priv->system_connection,
+			message,
+			-1, &error);
+		dbus_message_unref (message);
+
+		if (dbus_error_is_set (&error))
+		{
+			gs_debug ("%s raised:\n %s\n\n", error.name, error.message);
+			dbus_error_free (&error);
+			return NULL;
+		}
+
+		dbus_message_iter_init (reply, &reply_iter);
+		dbus_message_iter_get_basic (&reply_iter, &ssid);
+
+		dbus_message_unref (reply);
+
+		return g_strdup (ssid);
 	}
 #endif
 
