@@ -434,9 +434,9 @@ connect_presence_watcher (GSWatcher *watcher)
 
 	error = NULL;
 	watcher->priv->presence_proxy = dbus_g_proxy_new_for_name_owner (bus,
-	                                "org.mate.SessionManager",
-	                                "/org/mate/SessionManager/Presence",
-	                                "org.mate.SessionManager.Presence",
+	                                "org.gnome.SessionManager",
+	                                "/org/gnome/SessionManager/Presence",
+	                                "org.gnome.SessionManager.Presence",
 	                                &error);
 	if (watcher->priv->presence_proxy != NULL)
 	{
@@ -463,7 +463,7 @@ connect_presence_watcher (GSWatcher *watcher)
 
 		proxy = dbus_g_proxy_new_from_proxy (watcher->priv->presence_proxy,
 		                                     "org.freedesktop.DBus.Properties",
-		                                     "/org/mate/SessionManager/Presence");
+		                                     "/org/gnome/SessionManager/Presence");
 		if (proxy != NULL)
 		{
 			guint       status;
@@ -477,7 +477,7 @@ connect_presence_watcher (GSWatcher *watcher)
 			dbus_g_proxy_call (proxy,
 			                   "Get",
 			                   &error,
-			                   G_TYPE_STRING, "org.mate.SessionManager.Presence",
+			                   G_TYPE_STRING, "org.gnome.SessionManager.Presence",
 			                   G_TYPE_STRING, "status",
 			                   G_TYPE_INVALID,
 			                   G_TYPE_VALUE, &value,
@@ -500,7 +500,7 @@ connect_presence_watcher (GSWatcher *watcher)
 			dbus_g_proxy_call (proxy,
 			                   "Get",
 			                   &error,
-			                   G_TYPE_STRING, "org.mate.SessionManager.Presence",
+			                   G_TYPE_STRING, "org.gnome.SessionManager.Presence",
 			                   G_TYPE_STRING, "status-text",
 			                   G_TYPE_INVALID,
 			                   G_TYPE_VALUE, &value,
@@ -592,11 +592,7 @@ disable_builtin_screensaver (GSWatcher *watcher,
 	int desired_server_timeout, desired_server_interval;
 	int desired_prefer_blank,   desired_allow_exp;
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	XGetScreenSaver (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
-#else
-	XGetScreenSaver (GDK_DISPLAY (),
-#endif
 	                 &current_server_timeout,
 	                 &current_server_interval,
 	                 &current_prefer_blank,
@@ -635,31 +631,19 @@ disable_builtin_screensaver (GSWatcher *watcher,
 		          (desired_prefer_blank ? "blank" : "noblank"),
 		          (desired_allow_exp ? "expose" : "noexpose"));
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		XSetScreenSaver (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()),
-#else
-		XSetScreenSaver (GDK_DISPLAY (),
-#endif
 		                 desired_server_timeout,
 		                 desired_server_interval,
 		                 desired_prefer_blank,
 		                 desired_allow_exp);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 		XSync (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), FALSE);
-#else
-		XSync (GDK_DISPLAY (), FALSE);
-#endif
 	}
 
 	if (unblank_screen)
 	{
 		/* Turn off the server builtin saver if it is now running. */
-#if GTK_CHECK_VERSION (3, 0, 0)
 		XForceScreenSaver (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()), ScreenSaverReset);
-#else
-		XForceScreenSaver (GDK_DISPLAY (), ScreenSaverReset);
-#endif
 	}
 }
 
