@@ -499,10 +499,6 @@ main (int    argc,
 	textdomain (GETTEXT_PACKAGE);
 #endif
 
-#if !GLIB_CHECK_VERSION (2, 36, 0)
-	g_type_init ();
-#endif
-
 	g_set_prgname (argv[0]);
 
 	if (setlocale (LC_ALL, "") == NULL)
